.. _methods_stats:

Statistical methods
*******************


.. _methods_stats_bayes:

Bayesian Statistics
=====================================

Bayes theorem, priors, import from MLW thesis


.. _methods_stats_posterior:

Posterior
=========
How the posterior distributions are drawn, import from MLW thesis
